---
layout: post
title: "Restoring the TI 99/4A, ep. 2"
date: 2025-04-20 15:00:00 +0200
comments: true
categories:
---

## A detour with the power supply

Once during testing, I noticed smoke coming from the power supply board, and identified the origin in a charred resistor R6. Replacing R6 resulted in another charred resistor having let the magic smoke out.

At this stage, I was wisely advised to check for an obvious short on any on the power nets, but that wasn't the case. Checking the resistance between GND and each of the power supply pins, I found:
* between +5V and GND I'm seeing 180/249 Ω
* between +12V and GND: 464/314 Ω
* between -5V and GND: 271/464 Ω

Looking at the power supply board, I reasoned:
* Q1/Q2 form a Sziklai pair providing power output after the +5V regulation stage, and R6 is a bleeder resistor across Q2's BE junction, meant to improve the frequency response (and turn-off time, but I guess that's not really relevant in a regulation application)
* So, the voltage across R6, being the VBE of Q2, should be **no more than a diode drop**(TIP31A VBE(on)=1.8V), which would mean 18 mA going through R6, dissipating 32 mW, nowhere near thermal danger
* So, could R6 catching fire hints at **Q2 failed open**?

So I went on to desolder Q2, and the reasoning seemed to confirm an open B/E junction.

{% figure caption:"Desoldered Q2 (failed TIP31A)" %}
![bad TIP31A](assets/TI-resto/20250412-bad-TIP31A.jpg)
{% endfigure %}
{% figure caption:"Replacement Q2 (new TIP31A)" %}
![good TIP31A](assets/TI-resto/20250412-good-TIP31A.jpg)
{% endfigure %}

After resoldering a new TIP31A (and replacing R6 again), I now seem to get the expected voltages again, with no sign of overheating at R6. :tada:

## Decision: brain transfer

With the power supply issue fixed, I ran again the diagnostics tree from the *TI 99/4A New Technician Guide* and still came to the same conclusion that the TMS9900 itself seemed at fault, since even though all expected signals were present (power and all four clocks), all memory lines were desperately quiet.

I therefore decided to go for a replacement (also socketing the chip while I was at it).

### Removing the old TMS9900

Let's face it, I did a poor job desoldering and removing the old TMS9900. Was it the Chinese desoldering pump, my lack of skill, a 40+ years old PCB, or a bit of all of these?

My main concern was to avoid damaging the PCB, but I had a hard time adjusting the right level of force to the pins. I'm not proud of the result, quite a few pins were broken in the process. :face_vomiting:

{% figure caption:"At this stage I really hoped that CPU was indeed dead" %}
![Badly damaged TMS9900](assets/TI-resto/20250413-botched-desolder.jpg)
{% endfigure %}

### Preparing for new TMS9900

I cleaned up the board and soldered new female header pins to receive the new CPU.

{% figure caption:"Shiny new female headers to receive the new CPU" %}
![New socket for TMS9900](assets/TI-resto/20250420-socket.jpg)
{% endfigure %}

Pre-power-up checks done:
* visual inspection of solders
* absence of shorts between adjacent pins
* absence of shorts with tracks going between two pins
* continuity of clock signals to clock generator
* continuity of data bus signals (to scratchpad RAM)
* continuity of address bus signals (to ROM)

Power-up checks with no CPU in the socket:
* power supplies
* clocks

### It's alive!!!

I super-carefully socketed the new TMS9900, trying to not bend any pin.
Powered it up with just sound connected, no display...
*And it's a beep!* No longer the dreaded continuous tone, but the familiar merry short beep of the home screen :tada:

Alright, let's now hook up a display!

{% figure caption:"It boots!" %}
![TI 99/4A home screen](assets/TI-resto/20250420-alive.jpg)
{% endfigure %}
